# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'message': 'str',
        'id': 'str',
        'state': 'int',
        'email': 'str',
        'password': 'str',
        'source': 'int',
        'description': 'str',
        'token': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'default_company_name': 'str',
        'plan_id': 'str',
        'seats': 'int',
        'country_code': 'str',
        'company_plan': 'bool',
        'phone_number': 'str',
        'approve_user': 'bool',
        'role': 'int',
        'forum_id': 'str',
        'recaptcha': 'str',
        'invite_friend_request': 'bool',
        'cad_system_at_signup': 'str',
        'eula_accepted': 'bool',
        'upgrade_to_education_plan': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'message': 'message',
        'id': 'id',
        'state': 'state',
        'email': 'email',
        'password': 'password',
        'source': 'source',
        'description': 'description',
        'token': 'token',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'default_company_name': 'defaultCompanyName',
        'plan_id': 'planId',
        'seats': 'seats',
        'country_code': 'countryCode',
        'company_plan': 'companyPlan',
        'phone_number': 'phoneNumber',
        'approve_user': 'approveUser',
        'role': 'role',
        'forum_id': 'forumId',
        'recaptcha': 'recaptcha',
        'invite_friend_request': 'inviteFriendRequest',
        'cad_system_at_signup': 'cadSystemAtSignup',
        'eula_accepted': 'eulaAccepted',
        'upgrade_to_education_plan': 'upgradeToEducationPlan'
    }

    def __init__(self, name=None, message=None, id=None, state=None, email=None, password=None, source=None, description=None, token=None, first_name=None, last_name=None, default_company_name=None, plan_id=None, seats=None, country_code=None, company_plan=None, phone_number=None, approve_user=None, role=None, forum_id=None, recaptcha=None, invite_friend_request=None, cad_system_at_signup=None, eula_accepted=None, upgrade_to_education_plan=None):  # noqa: E501
        """BTUserParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._message = None
        self._id = None
        self._state = None
        self._email = None
        self._password = None
        self._source = None
        self._description = None
        self._token = None
        self._first_name = None
        self._last_name = None
        self._default_company_name = None
        self._plan_id = None
        self._seats = None
        self._country_code = None
        self._company_plan = None
        self._phone_number = None
        self._approve_user = None
        self._role = None
        self._forum_id = None
        self._recaptcha = None
        self._invite_friend_request = None
        self._cad_system_at_signup = None
        self._eula_accepted = None
        self._upgrade_to_education_plan = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if message is not None:
            self.message = message
        if id is not None:
            self.id = id
        if state is not None:
            self.state = state
        if email is not None:
            self.email = email
        if password is not None:
            self.password = password
        if source is not None:
            self.source = source
        if description is not None:
            self.description = description
        if token is not None:
            self.token = token
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if default_company_name is not None:
            self.default_company_name = default_company_name
        if plan_id is not None:
            self.plan_id = plan_id
        if seats is not None:
            self.seats = seats
        if country_code is not None:
            self.country_code = country_code
        if company_plan is not None:
            self.company_plan = company_plan
        if phone_number is not None:
            self.phone_number = phone_number
        if approve_user is not None:
            self.approve_user = approve_user
        if role is not None:
            self.role = role
        if forum_id is not None:
            self.forum_id = forum_id
        if recaptcha is not None:
            self.recaptcha = recaptcha
        if invite_friend_request is not None:
            self.invite_friend_request = invite_friend_request
        if cad_system_at_signup is not None:
            self.cad_system_at_signup = cad_system_at_signup
        if eula_accepted is not None:
            self.eula_accepted = eula_accepted
        if upgrade_to_education_plan is not None:
            self.upgrade_to_education_plan = upgrade_to_education_plan

    @property
    def name(self):
        """Gets the name of this BTUserParams.  # noqa: E501


        :return: The name of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTUserParams.


        :param name: The name of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def message(self):
        """Gets the message of this BTUserParams.  # noqa: E501


        :return: The message of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BTUserParams.


        :param message: The message of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def id(self):
        """Gets the id of this BTUserParams.  # noqa: E501


        :return: The id of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTUserParams.


        :param id: The id of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def state(self):
        """Gets the state of this BTUserParams.  # noqa: E501


        :return: The state of this BTUserParams.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTUserParams.


        :param state: The state of this BTUserParams.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def email(self):
        """Gets the email of this BTUserParams.  # noqa: E501


        :return: The email of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTUserParams.


        :param email: The email of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def password(self):
        """Gets the password of this BTUserParams.  # noqa: E501


        :return: The password of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this BTUserParams.


        :param password: The password of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def source(self):
        """Gets the source of this BTUserParams.  # noqa: E501


        :return: The source of this BTUserParams.  # noqa: E501
        :rtype: int
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this BTUserParams.


        :param source: The source of this BTUserParams.  # noqa: E501
        :type: int
        """

        self._source = source

    @property
    def description(self):
        """Gets the description of this BTUserParams.  # noqa: E501


        :return: The description of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTUserParams.


        :param description: The description of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def token(self):
        """Gets the token of this BTUserParams.  # noqa: E501


        :return: The token of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this BTUserParams.


        :param token: The token of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def first_name(self):
        """Gets the first_name of this BTUserParams.  # noqa: E501


        :return: The first_name of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this BTUserParams.


        :param first_name: The first_name of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this BTUserParams.  # noqa: E501


        :return: The last_name of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this BTUserParams.


        :param last_name: The last_name of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def default_company_name(self):
        """Gets the default_company_name of this BTUserParams.  # noqa: E501


        :return: The default_company_name of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._default_company_name

    @default_company_name.setter
    def default_company_name(self, default_company_name):
        """Sets the default_company_name of this BTUserParams.


        :param default_company_name: The default_company_name of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._default_company_name = default_company_name

    @property
    def plan_id(self):
        """Gets the plan_id of this BTUserParams.  # noqa: E501


        :return: The plan_id of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTUserParams.


        :param plan_id: The plan_id of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def seats(self):
        """Gets the seats of this BTUserParams.  # noqa: E501


        :return: The seats of this BTUserParams.  # noqa: E501
        :rtype: int
        """
        return self._seats

    @seats.setter
    def seats(self, seats):
        """Sets the seats of this BTUserParams.


        :param seats: The seats of this BTUserParams.  # noqa: E501
        :type: int
        """

        self._seats = seats

    @property
    def country_code(self):
        """Gets the country_code of this BTUserParams.  # noqa: E501


        :return: The country_code of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this BTUserParams.


        :param country_code: The country_code of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def company_plan(self):
        """Gets the company_plan of this BTUserParams.  # noqa: E501


        :return: The company_plan of this BTUserParams.  # noqa: E501
        :rtype: bool
        """
        return self._company_plan

    @company_plan.setter
    def company_plan(self, company_plan):
        """Sets the company_plan of this BTUserParams.


        :param company_plan: The company_plan of this BTUserParams.  # noqa: E501
        :type: bool
        """

        self._company_plan = company_plan

    @property
    def phone_number(self):
        """Gets the phone_number of this BTUserParams.  # noqa: E501


        :return: The phone_number of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this BTUserParams.


        :param phone_number: The phone_number of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def approve_user(self):
        """Gets the approve_user of this BTUserParams.  # noqa: E501


        :return: The approve_user of this BTUserParams.  # noqa: E501
        :rtype: bool
        """
        return self._approve_user

    @approve_user.setter
    def approve_user(self, approve_user):
        """Sets the approve_user of this BTUserParams.


        :param approve_user: The approve_user of this BTUserParams.  # noqa: E501
        :type: bool
        """

        self._approve_user = approve_user

    @property
    def role(self):
        """Gets the role of this BTUserParams.  # noqa: E501


        :return: The role of this BTUserParams.  # noqa: E501
        :rtype: int
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this BTUserParams.


        :param role: The role of this BTUserParams.  # noqa: E501
        :type: int
        """

        self._role = role

    @property
    def forum_id(self):
        """Gets the forum_id of this BTUserParams.  # noqa: E501


        :return: The forum_id of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._forum_id

    @forum_id.setter
    def forum_id(self, forum_id):
        """Sets the forum_id of this BTUserParams.


        :param forum_id: The forum_id of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._forum_id = forum_id

    @property
    def recaptcha(self):
        """Gets the recaptcha of this BTUserParams.  # noqa: E501


        :return: The recaptcha of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._recaptcha

    @recaptcha.setter
    def recaptcha(self, recaptcha):
        """Sets the recaptcha of this BTUserParams.


        :param recaptcha: The recaptcha of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._recaptcha = recaptcha

    @property
    def invite_friend_request(self):
        """Gets the invite_friend_request of this BTUserParams.  # noqa: E501


        :return: The invite_friend_request of this BTUserParams.  # noqa: E501
        :rtype: bool
        """
        return self._invite_friend_request

    @invite_friend_request.setter
    def invite_friend_request(self, invite_friend_request):
        """Sets the invite_friend_request of this BTUserParams.


        :param invite_friend_request: The invite_friend_request of this BTUserParams.  # noqa: E501
        :type: bool
        """

        self._invite_friend_request = invite_friend_request

    @property
    def cad_system_at_signup(self):
        """Gets the cad_system_at_signup of this BTUserParams.  # noqa: E501


        :return: The cad_system_at_signup of this BTUserParams.  # noqa: E501
        :rtype: str
        """
        return self._cad_system_at_signup

    @cad_system_at_signup.setter
    def cad_system_at_signup(self, cad_system_at_signup):
        """Sets the cad_system_at_signup of this BTUserParams.


        :param cad_system_at_signup: The cad_system_at_signup of this BTUserParams.  # noqa: E501
        :type: str
        """

        self._cad_system_at_signup = cad_system_at_signup

    @property
    def eula_accepted(self):
        """Gets the eula_accepted of this BTUserParams.  # noqa: E501


        :return: The eula_accepted of this BTUserParams.  # noqa: E501
        :rtype: bool
        """
        return self._eula_accepted

    @eula_accepted.setter
    def eula_accepted(self, eula_accepted):
        """Sets the eula_accepted of this BTUserParams.


        :param eula_accepted: The eula_accepted of this BTUserParams.  # noqa: E501
        :type: bool
        """

        self._eula_accepted = eula_accepted

    @property
    def upgrade_to_education_plan(self):
        """Gets the upgrade_to_education_plan of this BTUserParams.  # noqa: E501


        :return: The upgrade_to_education_plan of this BTUserParams.  # noqa: E501
        :rtype: bool
        """
        return self._upgrade_to_education_plan

    @upgrade_to_education_plan.setter
    def upgrade_to_education_plan(self, upgrade_to_education_plan):
        """Sets the upgrade_to_education_plan of this BTUserParams.


        :param upgrade_to_education_plan: The upgrade_to_education_plan of this BTUserParams.  # noqa: E501
        :type: bool
        """

        self._upgrade_to_education_plan = upgrade_to_education_plan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDrawingParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location': 'BTElementLocationParams',
        'size': 'str',
        'language': 'str',
        'decimal_separator': 'str',
        'revision': 'str',
        'part_number': 'str',
        'units': 'str',
        'compute_intersection': 'bool',
        'document_microversion_id': 'str',
        'hidden_lines': 'str',
        'include_surfaces': 'bool',
        'is_surface': 'bool',
        'pure_sketch': 'bool',
        'is_sketch_only': 'bool',
        'workspace_id': 'str',
        'element_id': 'str',
        'part_query': 'str',
        'part_id': 'str',
        'external_document_version_id': 'str',
        'element_configuration': 'str',
        'template_document_id': 'str',
        'template_workspace_id': 'str',
        'template_name': 'str',
        'template_args': 'list[str]',
        'template_element_id': 'str',
        'drawing_name': 'str',
        'projection': 'str',
        'standard': 'str',
        'border': 'bool',
        'titleblock': 'bool',
        'number_horizontal_zones': 'int',
        'number_vertical_zones': 'int',
        'start_zones': 'str',
        'external_document_id': 'str',
        'document_id': 'str',
        'sketch_id': 'str',
        'sketch_ids': 'list[str]',
        'element_microversion_id': 'str',
        'views': 'str',
        'template_version_id': 'str',
        'model_type': 'str'
    }

    attribute_map = {
        'location': 'location',
        'size': 'size',
        'language': 'language',
        'decimal_separator': 'decimalSeparator',
        'revision': 'revision',
        'part_number': 'partNumber',
        'units': 'units',
        'compute_intersection': 'computeIntersection',
        'document_microversion_id': 'documentMicroversionId',
        'hidden_lines': 'hiddenLines',
        'include_surfaces': 'includeSurfaces',
        'is_surface': 'isSurface',
        'pure_sketch': 'pureSketch',
        'is_sketch_only': 'isSketchOnly',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'part_query': 'partQuery',
        'part_id': 'partId',
        'external_document_version_id': 'externalDocumentVersionId',
        'element_configuration': 'elementConfiguration',
        'template_document_id': 'templateDocumentId',
        'template_workspace_id': 'templateWorkspaceId',
        'template_name': 'templateName',
        'template_args': 'templateArgs',
        'template_element_id': 'templateElementId',
        'drawing_name': 'drawingName',
        'projection': 'projection',
        'standard': 'standard',
        'border': 'border',
        'titleblock': 'titleblock',
        'number_horizontal_zones': 'numberHorizontalZones',
        'number_vertical_zones': 'numberVerticalZones',
        'start_zones': 'startZones',
        'external_document_id': 'externalDocumentId',
        'document_id': 'documentId',
        'sketch_id': 'sketchId',
        'sketch_ids': 'sketchIds',
        'element_microversion_id': 'elementMicroversionId',
        'views': 'views',
        'template_version_id': 'templateVersionId',
        'model_type': 'modelType'
    }

    def __init__(self, location=None, size=None, language=None, decimal_separator=None, revision=None, part_number=None, units=None, compute_intersection=None, document_microversion_id=None, hidden_lines=None, include_surfaces=None, is_surface=None, pure_sketch=None, is_sketch_only=None, workspace_id=None, element_id=None, part_query=None, part_id=None, external_document_version_id=None, element_configuration=None, template_document_id=None, template_workspace_id=None, template_name=None, template_args=None, template_element_id=None, drawing_name=None, projection=None, standard=None, border=None, titleblock=None, number_horizontal_zones=None, number_vertical_zones=None, start_zones=None, external_document_id=None, document_id=None, sketch_id=None, sketch_ids=None, element_microversion_id=None, views=None, template_version_id=None, model_type=None):  # noqa: E501
        """BTDrawingParams - a model defined in OpenAPI"""  # noqa: E501

        self._location = None
        self._size = None
        self._language = None
        self._decimal_separator = None
        self._revision = None
        self._part_number = None
        self._units = None
        self._compute_intersection = None
        self._document_microversion_id = None
        self._hidden_lines = None
        self._include_surfaces = None
        self._is_surface = None
        self._pure_sketch = None
        self._is_sketch_only = None
        self._workspace_id = None
        self._element_id = None
        self._part_query = None
        self._part_id = None
        self._external_document_version_id = None
        self._element_configuration = None
        self._template_document_id = None
        self._template_workspace_id = None
        self._template_name = None
        self._template_args = None
        self._template_element_id = None
        self._drawing_name = None
        self._projection = None
        self._standard = None
        self._border = None
        self._titleblock = None
        self._number_horizontal_zones = None
        self._number_vertical_zones = None
        self._start_zones = None
        self._external_document_id = None
        self._document_id = None
        self._sketch_id = None
        self._sketch_ids = None
        self._element_microversion_id = None
        self._views = None
        self._template_version_id = None
        self._model_type = None
        self.discriminator = None

        if location is not None:
            self.location = location
        if size is not None:
            self.size = size
        if language is not None:
            self.language = language
        if decimal_separator is not None:
            self.decimal_separator = decimal_separator
        if revision is not None:
            self.revision = revision
        if part_number is not None:
            self.part_number = part_number
        if units is not None:
            self.units = units
        if compute_intersection is not None:
            self.compute_intersection = compute_intersection
        if document_microversion_id is not None:
            self.document_microversion_id = document_microversion_id
        if hidden_lines is not None:
            self.hidden_lines = hidden_lines
        if include_surfaces is not None:
            self.include_surfaces = include_surfaces
        if is_surface is not None:
            self.is_surface = is_surface
        if pure_sketch is not None:
            self.pure_sketch = pure_sketch
        if is_sketch_only is not None:
            self.is_sketch_only = is_sketch_only
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if part_query is not None:
            self.part_query = part_query
        if part_id is not None:
            self.part_id = part_id
        if external_document_version_id is not None:
            self.external_document_version_id = external_document_version_id
        if element_configuration is not None:
            self.element_configuration = element_configuration
        if template_document_id is not None:
            self.template_document_id = template_document_id
        if template_workspace_id is not None:
            self.template_workspace_id = template_workspace_id
        if template_name is not None:
            self.template_name = template_name
        if template_args is not None:
            self.template_args = template_args
        if template_element_id is not None:
            self.template_element_id = template_element_id
        if drawing_name is not None:
            self.drawing_name = drawing_name
        if projection is not None:
            self.projection = projection
        if standard is not None:
            self.standard = standard
        if border is not None:
            self.border = border
        if titleblock is not None:
            self.titleblock = titleblock
        if number_horizontal_zones is not None:
            self.number_horizontal_zones = number_horizontal_zones
        if number_vertical_zones is not None:
            self.number_vertical_zones = number_vertical_zones
        if start_zones is not None:
            self.start_zones = start_zones
        if external_document_id is not None:
            self.external_document_id = external_document_id
        if document_id is not None:
            self.document_id = document_id
        if sketch_id is not None:
            self.sketch_id = sketch_id
        if sketch_ids is not None:
            self.sketch_ids = sketch_ids
        if element_microversion_id is not None:
            self.element_microversion_id = element_microversion_id
        if views is not None:
            self.views = views
        if template_version_id is not None:
            self.template_version_id = template_version_id
        if model_type is not None:
            self.model_type = model_type

    @property
    def location(self):
        """Gets the location of this BTDrawingParams.  # noqa: E501


        :return: The location of this BTDrawingParams.  # noqa: E501
        :rtype: BTElementLocationParams
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this BTDrawingParams.


        :param location: The location of this BTDrawingParams.  # noqa: E501
        :type: BTElementLocationParams
        """

        self._location = location

    @property
    def size(self):
        """Gets the size of this BTDrawingParams.  # noqa: E501


        :return: The size of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this BTDrawingParams.


        :param size: The size of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def language(self):
        """Gets the language of this BTDrawingParams.  # noqa: E501


        :return: The language of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this BTDrawingParams.


        :param language: The language of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def decimal_separator(self):
        """Gets the decimal_separator of this BTDrawingParams.  # noqa: E501


        :return: The decimal_separator of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._decimal_separator

    @decimal_separator.setter
    def decimal_separator(self, decimal_separator):
        """Sets the decimal_separator of this BTDrawingParams.


        :param decimal_separator: The decimal_separator of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._decimal_separator = decimal_separator

    @property
    def revision(self):
        """Gets the revision of this BTDrawingParams.  # noqa: E501


        :return: The revision of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTDrawingParams.


        :param revision: The revision of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def part_number(self):
        """Gets the part_number of this BTDrawingParams.  # noqa: E501


        :return: The part_number of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTDrawingParams.


        :param part_number: The part_number of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def units(self):
        """Gets the units of this BTDrawingParams.  # noqa: E501


        :return: The units of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this BTDrawingParams.


        :param units: The units of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._units = units

    @property
    def compute_intersection(self):
        """Gets the compute_intersection of this BTDrawingParams.  # noqa: E501


        :return: The compute_intersection of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._compute_intersection

    @compute_intersection.setter
    def compute_intersection(self, compute_intersection):
        """Sets the compute_intersection of this BTDrawingParams.


        :param compute_intersection: The compute_intersection of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._compute_intersection = compute_intersection

    @property
    def document_microversion_id(self):
        """Gets the document_microversion_id of this BTDrawingParams.  # noqa: E501


        :return: The document_microversion_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._document_microversion_id

    @document_microversion_id.setter
    def document_microversion_id(self, document_microversion_id):
        """Sets the document_microversion_id of this BTDrawingParams.


        :param document_microversion_id: The document_microversion_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._document_microversion_id = document_microversion_id

    @property
    def hidden_lines(self):
        """Gets the hidden_lines of this BTDrawingParams.  # noqa: E501


        :return: The hidden_lines of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._hidden_lines

    @hidden_lines.setter
    def hidden_lines(self, hidden_lines):
        """Sets the hidden_lines of this BTDrawingParams.


        :param hidden_lines: The hidden_lines of this BTDrawingParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["DRAFTING", "EXCLUDED", "MARKED"]  # noqa: E501
        if hidden_lines not in allowed_values:
            raise ValueError(
                "Invalid value for `hidden_lines` ({0}), must be one of {1}"  # noqa: E501
                .format(hidden_lines, allowed_values)
            )

        self._hidden_lines = hidden_lines

    @property
    def include_surfaces(self):
        """Gets the include_surfaces of this BTDrawingParams.  # noqa: E501


        :return: The include_surfaces of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_surfaces

    @include_surfaces.setter
    def include_surfaces(self, include_surfaces):
        """Sets the include_surfaces of this BTDrawingParams.


        :param include_surfaces: The include_surfaces of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._include_surfaces = include_surfaces

    @property
    def is_surface(self):
        """Gets the is_surface of this BTDrawingParams.  # noqa: E501


        :return: The is_surface of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_surface

    @is_surface.setter
    def is_surface(self, is_surface):
        """Sets the is_surface of this BTDrawingParams.


        :param is_surface: The is_surface of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._is_surface = is_surface

    @property
    def pure_sketch(self):
        """Gets the pure_sketch of this BTDrawingParams.  # noqa: E501


        :return: The pure_sketch of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._pure_sketch

    @pure_sketch.setter
    def pure_sketch(self, pure_sketch):
        """Sets the pure_sketch of this BTDrawingParams.


        :param pure_sketch: The pure_sketch of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._pure_sketch = pure_sketch

    @property
    def is_sketch_only(self):
        """Gets the is_sketch_only of this BTDrawingParams.  # noqa: E501


        :return: The is_sketch_only of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_sketch_only

    @is_sketch_only.setter
    def is_sketch_only(self, is_sketch_only):
        """Sets the is_sketch_only of this BTDrawingParams.


        :param is_sketch_only: The is_sketch_only of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._is_sketch_only = is_sketch_only

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTDrawingParams.  # noqa: E501


        :return: The workspace_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTDrawingParams.


        :param workspace_id: The workspace_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTDrawingParams.  # noqa: E501


        :return: The element_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTDrawingParams.


        :param element_id: The element_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def part_query(self):
        """Gets the part_query of this BTDrawingParams.  # noqa: E501


        :return: The part_query of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._part_query

    @part_query.setter
    def part_query(self, part_query):
        """Sets the part_query of this BTDrawingParams.


        :param part_query: The part_query of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._part_query = part_query

    @property
    def part_id(self):
        """Gets the part_id of this BTDrawingParams.  # noqa: E501


        :return: The part_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTDrawingParams.


        :param part_id: The part_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def external_document_version_id(self):
        """Gets the external_document_version_id of this BTDrawingParams.  # noqa: E501


        :return: The external_document_version_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._external_document_version_id

    @external_document_version_id.setter
    def external_document_version_id(self, external_document_version_id):
        """Sets the external_document_version_id of this BTDrawingParams.


        :param external_document_version_id: The external_document_version_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._external_document_version_id = external_document_version_id

    @property
    def element_configuration(self):
        """Gets the element_configuration of this BTDrawingParams.  # noqa: E501


        :return: The element_configuration of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._element_configuration

    @element_configuration.setter
    def element_configuration(self, element_configuration):
        """Sets the element_configuration of this BTDrawingParams.


        :param element_configuration: The element_configuration of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._element_configuration = element_configuration

    @property
    def template_document_id(self):
        """Gets the template_document_id of this BTDrawingParams.  # noqa: E501


        :return: The template_document_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._template_document_id

    @template_document_id.setter
    def template_document_id(self, template_document_id):
        """Sets the template_document_id of this BTDrawingParams.


        :param template_document_id: The template_document_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._template_document_id = template_document_id

    @property
    def template_workspace_id(self):
        """Gets the template_workspace_id of this BTDrawingParams.  # noqa: E501


        :return: The template_workspace_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._template_workspace_id

    @template_workspace_id.setter
    def template_workspace_id(self, template_workspace_id):
        """Sets the template_workspace_id of this BTDrawingParams.


        :param template_workspace_id: The template_workspace_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._template_workspace_id = template_workspace_id

    @property
    def template_name(self):
        """Gets the template_name of this BTDrawingParams.  # noqa: E501


        :return: The template_name of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this BTDrawingParams.


        :param template_name: The template_name of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._template_name = template_name

    @property
    def template_args(self):
        """Gets the template_args of this BTDrawingParams.  # noqa: E501


        :return: The template_args of this BTDrawingParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._template_args

    @template_args.setter
    def template_args(self, template_args):
        """Sets the template_args of this BTDrawingParams.


        :param template_args: The template_args of this BTDrawingParams.  # noqa: E501
        :type: list[str]
        """

        self._template_args = template_args

    @property
    def template_element_id(self):
        """Gets the template_element_id of this BTDrawingParams.  # noqa: E501


        :return: The template_element_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._template_element_id

    @template_element_id.setter
    def template_element_id(self, template_element_id):
        """Sets the template_element_id of this BTDrawingParams.


        :param template_element_id: The template_element_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._template_element_id = template_element_id

    @property
    def drawing_name(self):
        """Gets the drawing_name of this BTDrawingParams.  # noqa: E501


        :return: The drawing_name of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._drawing_name

    @drawing_name.setter
    def drawing_name(self, drawing_name):
        """Sets the drawing_name of this BTDrawingParams.


        :param drawing_name: The drawing_name of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._drawing_name = drawing_name

    @property
    def projection(self):
        """Gets the projection of this BTDrawingParams.  # noqa: E501


        :return: The projection of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._projection

    @projection.setter
    def projection(self, projection):
        """Sets the projection of this BTDrawingParams.


        :param projection: The projection of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._projection = projection

    @property
    def standard(self):
        """Gets the standard of this BTDrawingParams.  # noqa: E501


        :return: The standard of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this BTDrawingParams.


        :param standard: The standard of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._standard = standard

    @property
    def border(self):
        """Gets the border of this BTDrawingParams.  # noqa: E501


        :return: The border of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._border

    @border.setter
    def border(self, border):
        """Sets the border of this BTDrawingParams.


        :param border: The border of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._border = border

    @property
    def titleblock(self):
        """Gets the titleblock of this BTDrawingParams.  # noqa: E501


        :return: The titleblock of this BTDrawingParams.  # noqa: E501
        :rtype: bool
        """
        return self._titleblock

    @titleblock.setter
    def titleblock(self, titleblock):
        """Sets the titleblock of this BTDrawingParams.


        :param titleblock: The titleblock of this BTDrawingParams.  # noqa: E501
        :type: bool
        """

        self._titleblock = titleblock

    @property
    def number_horizontal_zones(self):
        """Gets the number_horizontal_zones of this BTDrawingParams.  # noqa: E501


        :return: The number_horizontal_zones of this BTDrawingParams.  # noqa: E501
        :rtype: int
        """
        return self._number_horizontal_zones

    @number_horizontal_zones.setter
    def number_horizontal_zones(self, number_horizontal_zones):
        """Sets the number_horizontal_zones of this BTDrawingParams.


        :param number_horizontal_zones: The number_horizontal_zones of this BTDrawingParams.  # noqa: E501
        :type: int
        """

        self._number_horizontal_zones = number_horizontal_zones

    @property
    def number_vertical_zones(self):
        """Gets the number_vertical_zones of this BTDrawingParams.  # noqa: E501


        :return: The number_vertical_zones of this BTDrawingParams.  # noqa: E501
        :rtype: int
        """
        return self._number_vertical_zones

    @number_vertical_zones.setter
    def number_vertical_zones(self, number_vertical_zones):
        """Sets the number_vertical_zones of this BTDrawingParams.


        :param number_vertical_zones: The number_vertical_zones of this BTDrawingParams.  # noqa: E501
        :type: int
        """

        self._number_vertical_zones = number_vertical_zones

    @property
    def start_zones(self):
        """Gets the start_zones of this BTDrawingParams.  # noqa: E501


        :return: The start_zones of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._start_zones

    @start_zones.setter
    def start_zones(self, start_zones):
        """Sets the start_zones of this BTDrawingParams.


        :param start_zones: The start_zones of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._start_zones = start_zones

    @property
    def external_document_id(self):
        """Gets the external_document_id of this BTDrawingParams.  # noqa: E501


        :return: The external_document_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._external_document_id

    @external_document_id.setter
    def external_document_id(self, external_document_id):
        """Sets the external_document_id of this BTDrawingParams.


        :param external_document_id: The external_document_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._external_document_id = external_document_id

    @property
    def document_id(self):
        """Gets the document_id of this BTDrawingParams.  # noqa: E501


        :return: The document_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTDrawingParams.


        :param document_id: The document_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def sketch_id(self):
        """Gets the sketch_id of this BTDrawingParams.  # noqa: E501


        :return: The sketch_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._sketch_id

    @sketch_id.setter
    def sketch_id(self, sketch_id):
        """Sets the sketch_id of this BTDrawingParams.


        :param sketch_id: The sketch_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._sketch_id = sketch_id

    @property
    def sketch_ids(self):
        """Gets the sketch_ids of this BTDrawingParams.  # noqa: E501


        :return: The sketch_ids of this BTDrawingParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._sketch_ids

    @sketch_ids.setter
    def sketch_ids(self, sketch_ids):
        """Sets the sketch_ids of this BTDrawingParams.


        :param sketch_ids: The sketch_ids of this BTDrawingParams.  # noqa: E501
        :type: list[str]
        """

        self._sketch_ids = sketch_ids

    @property
    def element_microversion_id(self):
        """Gets the element_microversion_id of this BTDrawingParams.  # noqa: E501


        :return: The element_microversion_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._element_microversion_id

    @element_microversion_id.setter
    def element_microversion_id(self, element_microversion_id):
        """Sets the element_microversion_id of this BTDrawingParams.


        :param element_microversion_id: The element_microversion_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._element_microversion_id = element_microversion_id

    @property
    def views(self):
        """Gets the views of this BTDrawingParams.  # noqa: E501


        :return: The views of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._views

    @views.setter
    def views(self, views):
        """Sets the views of this BTDrawingParams.


        :param views: The views of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._views = views

    @property
    def template_version_id(self):
        """Gets the template_version_id of this BTDrawingParams.  # noqa: E501


        :return: The template_version_id of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._template_version_id

    @template_version_id.setter
    def template_version_id(self, template_version_id):
        """Sets the template_version_id of this BTDrawingParams.


        :param template_version_id: The template_version_id of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._template_version_id = template_version_id

    @property
    def model_type(self):
        """Gets the model_type of this BTDrawingParams.  # noqa: E501


        :return: The model_type of this BTDrawingParams.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this BTDrawingParams.


        :param model_type: The model_type of this BTDrawingParams.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDrawingParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBrokenOutEndCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upto_point3d': 'BTVector3d',
        'has_upto_point': 'bool',
        'has_offset': 'bool',
        'offset_distance': 'float',
        'offset_opposite_direction': 'bool',
        'upto_point': 'list[float]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'upto_point3d': 'uptoPoint3d',
        'has_upto_point': 'hasUptoPoint',
        'has_offset': 'hasOffset',
        'offset_distance': 'offsetDistance',
        'offset_opposite_direction': 'offsetOppositeDirection',
        'upto_point': 'uptoPoint',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, upto_point3d=None, has_upto_point=None, has_offset=None, offset_distance=None, offset_opposite_direction=None, upto_point=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTBrokenOutEndCondition - a model defined in OpenAPI"""  # noqa: E501

        self._upto_point3d = None
        self._has_upto_point = None
        self._has_offset = None
        self._offset_distance = None
        self._offset_opposite_direction = None
        self._upto_point = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if upto_point3d is not None:
            self.upto_point3d = upto_point3d
        if has_upto_point is not None:
            self.has_upto_point = has_upto_point
        if has_offset is not None:
            self.has_offset = has_offset
        if offset_distance is not None:
            self.offset_distance = offset_distance
        if offset_opposite_direction is not None:
            self.offset_opposite_direction = offset_opposite_direction
        if upto_point is not None:
            self.upto_point = upto_point
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def upto_point3d(self):
        """Gets the upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._upto_point3d

    @upto_point3d.setter
    def upto_point3d(self, upto_point3d):
        """Sets the upto_point3d of this BTBrokenOutEndCondition.


        :param upto_point3d: The upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501
        :type: BTVector3d
        """

        self._upto_point3d = upto_point3d

    @property
    def has_upto_point(self):
        """Gets the has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._has_upto_point

    @has_upto_point.setter
    def has_upto_point(self, has_upto_point):
        """Sets the has_upto_point of this BTBrokenOutEndCondition.


        :param has_upto_point: The has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._has_upto_point = has_upto_point

    @property
    def has_offset(self):
        """Gets the has_offset of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The has_offset of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._has_offset

    @has_offset.setter
    def has_offset(self, has_offset):
        """Sets the has_offset of this BTBrokenOutEndCondition.


        :param has_offset: The has_offset of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._has_offset = has_offset

    @property
    def offset_distance(self):
        """Gets the offset_distance of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The offset_distance of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: float
        """
        return self._offset_distance

    @offset_distance.setter
    def offset_distance(self, offset_distance):
        """Sets the offset_distance of this BTBrokenOutEndCondition.


        :param offset_distance: The offset_distance of this BTBrokenOutEndCondition.  # noqa: E501
        :type: float
        """

        self._offset_distance = offset_distance

    @property
    def offset_opposite_direction(self):
        """Gets the offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._offset_opposite_direction

    @offset_opposite_direction.setter
    def offset_opposite_direction(self, offset_opposite_direction):
        """Sets the offset_opposite_direction of this BTBrokenOutEndCondition.


        :param offset_opposite_direction: The offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._offset_opposite_direction = offset_opposite_direction

    @property
    def upto_point(self):
        """Gets the upto_point of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: list[float]
        """
        return self._upto_point

    @upto_point.setter
    def upto_point(self, upto_point):
        """Sets the upto_point of this BTBrokenOutEndCondition.


        :param upto_point: The upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :type: list[float]
        """

        self._upto_point = upto_point

    @property
    def type_id(self):
        """Gets the type_id of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The type_id of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTBrokenOutEndCondition.


        :param type_id: The type_id of this BTBrokenOutEndCondition.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The connection_source of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTBrokenOutEndCondition.


        :param connection_source: The connection_source of this BTBrokenOutEndCondition.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The export_type_name of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTBrokenOutEndCondition.


        :param export_type_name: The export_type_name of this BTBrokenOutEndCondition.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The unknown_class of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTBrokenOutEndCondition.


        :param unknown_class: The unknown_class of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBrokenOutEndCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAddressInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'state': 'str',
        'address': 'str',
        'country': 'str',
        'city': 'str',
        'state_code': 'str',
        'country_code': 'str',
        'zip': 'str'
    }

    attribute_map = {
        'id': 'id',
        'state': 'state',
        'address': 'address',
        'country': 'country',
        'city': 'city',
        'state_code': 'stateCode',
        'country_code': 'countryCode',
        'zip': 'zip'
    }

    def __init__(self, id=None, state=None, address=None, country=None, city=None, state_code=None, country_code=None, zip=None):  # noqa: E501
        """BTAddressInfo - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._state = None
        self._address = None
        self._country = None
        self._city = None
        self._state_code = None
        self._country_code = None
        self._zip = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if state is not None:
            self.state = state
        if address is not None:
            self.address = address
        if country is not None:
            self.country = country
        if city is not None:
            self.city = city
        if state_code is not None:
            self.state_code = state_code
        if country_code is not None:
            self.country_code = country_code
        if zip is not None:
            self.zip = zip

    @property
    def id(self):
        """Gets the id of this BTAddressInfo.  # noqa: E501


        :return: The id of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTAddressInfo.


        :param id: The id of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def state(self):
        """Gets the state of this BTAddressInfo.  # noqa: E501


        :return: The state of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTAddressInfo.


        :param state: The state of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def address(self):
        """Gets the address of this BTAddressInfo.  # noqa: E501


        :return: The address of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this BTAddressInfo.


        :param address: The address of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def country(self):
        """Gets the country of this BTAddressInfo.  # noqa: E501


        :return: The country of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this BTAddressInfo.


        :param country: The country of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def city(self):
        """Gets the city of this BTAddressInfo.  # noqa: E501


        :return: The city of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this BTAddressInfo.


        :param city: The city of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state_code(self):
        """Gets the state_code of this BTAddressInfo.  # noqa: E501


        :return: The state_code of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._state_code

    @state_code.setter
    def state_code(self, state_code):
        """Sets the state_code of this BTAddressInfo.


        :param state_code: The state_code of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._state_code = state_code

    @property
    def country_code(self):
        """Gets the country_code of this BTAddressInfo.  # noqa: E501


        :return: The country_code of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this BTAddressInfo.


        :param country_code: The country_code of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def zip(self):
        """Gets the zip of this BTAddressInfo.  # noqa: E501


        :return: The zip of this BTAddressInfo.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this BTAddressInfo.


        :param zip: The zip of this BTAddressInfo.  # noqa: E501
        :type: str
        """

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAddressInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserUpdateParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'default_company_name': 'str',
        'country_code': 'str',
        'old_password': 'str',
        'new_password': 'str',
        'phone_number': 'str',
        'forum_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'default_company_name': 'defaultCompanyName',
        'country_code': 'countryCode',
        'old_password': 'oldPassword',
        'new_password': 'newPassword',
        'phone_number': 'phoneNumber',
        'forum_id': 'forumId'
    }

    def __init__(self, name=None, id=None, description=None, first_name=None, last_name=None, default_company_name=None, country_code=None, old_password=None, new_password=None, phone_number=None, forum_id=None):  # noqa: E501
        """BTUserUpdateParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._description = None
        self._first_name = None
        self._last_name = None
        self._default_company_name = None
        self._country_code = None
        self._old_password = None
        self._new_password = None
        self._phone_number = None
        self._forum_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if description is not None:
            self.description = description
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if default_company_name is not None:
            self.default_company_name = default_company_name
        if country_code is not None:
            self.country_code = country_code
        if old_password is not None:
            self.old_password = old_password
        if new_password is not None:
            self.new_password = new_password
        if phone_number is not None:
            self.phone_number = phone_number
        if forum_id is not None:
            self.forum_id = forum_id

    @property
    def name(self):
        """Gets the name of this BTUserUpdateParams.  # noqa: E501


        :return: The name of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTUserUpdateParams.


        :param name: The name of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTUserUpdateParams.  # noqa: E501


        :return: The id of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTUserUpdateParams.


        :param id: The id of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def description(self):
        """Gets the description of this BTUserUpdateParams.  # noqa: E501


        :return: The description of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTUserUpdateParams.


        :param description: The description of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def first_name(self):
        """Gets the first_name of this BTUserUpdateParams.  # noqa: E501


        :return: The first_name of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this BTUserUpdateParams.


        :param first_name: The first_name of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this BTUserUpdateParams.  # noqa: E501


        :return: The last_name of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this BTUserUpdateParams.


        :param last_name: The last_name of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def default_company_name(self):
        """Gets the default_company_name of this BTUserUpdateParams.  # noqa: E501


        :return: The default_company_name of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._default_company_name

    @default_company_name.setter
    def default_company_name(self, default_company_name):
        """Sets the default_company_name of this BTUserUpdateParams.


        :param default_company_name: The default_company_name of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._default_company_name = default_company_name

    @property
    def country_code(self):
        """Gets the country_code of this BTUserUpdateParams.  # noqa: E501


        :return: The country_code of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this BTUserUpdateParams.


        :param country_code: The country_code of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def old_password(self):
        """Gets the old_password of this BTUserUpdateParams.  # noqa: E501


        :return: The old_password of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._old_password

    @old_password.setter
    def old_password(self, old_password):
        """Sets the old_password of this BTUserUpdateParams.


        :param old_password: The old_password of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._old_password = old_password

    @property
    def new_password(self):
        """Gets the new_password of this BTUserUpdateParams.  # noqa: E501


        :return: The new_password of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._new_password

    @new_password.setter
    def new_password(self, new_password):
        """Sets the new_password of this BTUserUpdateParams.


        :param new_password: The new_password of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._new_password = new_password

    @property
    def phone_number(self):
        """Gets the phone_number of this BTUserUpdateParams.  # noqa: E501


        :return: The phone_number of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this BTUserUpdateParams.


        :param phone_number: The phone_number of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def forum_id(self):
        """Gets the forum_id of this BTUserUpdateParams.  # noqa: E501


        :return: The forum_id of this BTUserUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._forum_id

    @forum_id.setter
    def forum_id(self, forum_id):
        """Sets the forum_id of this BTUserUpdateParams.


        :param forum_id: The forum_id of this BTUserUpdateParams.  # noqa: E501
        :type: str
        """

        self._forum_id = forum_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserUpdateParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAclParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'public': 'bool',
        'anonymous_access_allowed': 'bool',
        'anonymous_allows_export': 'bool',
        'document_id': 'str'
    }

    attribute_map = {
        'public': 'public',
        'anonymous_access_allowed': 'anonymousAccessAllowed',
        'anonymous_allows_export': 'anonymousAllowsExport',
        'document_id': 'documentId'
    }

    def __init__(self, public=None, anonymous_access_allowed=None, anonymous_allows_export=None, document_id=None):  # noqa: E501
        """BTAclParams - a model defined in OpenAPI"""  # noqa: E501

        self._public = None
        self._anonymous_access_allowed = None
        self._anonymous_allows_export = None
        self._document_id = None
        self.discriminator = None

        if public is not None:
            self.public = public
        if anonymous_access_allowed is not None:
            self.anonymous_access_allowed = anonymous_access_allowed
        if anonymous_allows_export is not None:
            self.anonymous_allows_export = anonymous_allows_export
        if document_id is not None:
            self.document_id = document_id

    @property
    def public(self):
        """Gets the public of this BTAclParams.  # noqa: E501


        :return: The public of this BTAclParams.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this BTAclParams.


        :param public: The public of this BTAclParams.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def anonymous_access_allowed(self):
        """Gets the anonymous_access_allowed of this BTAclParams.  # noqa: E501


        :return: The anonymous_access_allowed of this BTAclParams.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_access_allowed

    @anonymous_access_allowed.setter
    def anonymous_access_allowed(self, anonymous_access_allowed):
        """Sets the anonymous_access_allowed of this BTAclParams.


        :param anonymous_access_allowed: The anonymous_access_allowed of this BTAclParams.  # noqa: E501
        :type: bool
        """

        self._anonymous_access_allowed = anonymous_access_allowed

    @property
    def anonymous_allows_export(self):
        """Gets the anonymous_allows_export of this BTAclParams.  # noqa: E501


        :return: The anonymous_allows_export of this BTAclParams.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_allows_export

    @anonymous_allows_export.setter
    def anonymous_allows_export(self, anonymous_allows_export):
        """Sets the anonymous_allows_export of this BTAclParams.


        :param anonymous_allows_export: The anonymous_allows_export of this BTAclParams.  # noqa: E501
        :type: bool
        """

        self._anonymous_allows_export = anonymous_allows_export

    @property
    def document_id(self):
        """Gets the document_id of this BTAclParams.  # noqa: E501


        :return: The document_id of this BTAclParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTAclParams.


        :param document_id: The document_id of this BTAclParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAclParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTFeatureListResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'features': 'list[BTMFeature]',
        'is_complete': 'bool',
        'feature_states': 'dict(str, BTFeatureState)',
        'default_features': 'list[BTMFeature]',
        'imports': 'list[BTMImport]',
        'rollback_index': 'int',
        'bel_script_library_version': 'BTBelScriptLibraryVersion',
        'source_microversion': 'str',
        'reject_microversion_skew': 'bool',
        'serialization_version': 'str',
        'library_version': 'int',
        'microversion_skew': 'bool',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'features': 'features',
        'is_complete': 'isComplete',
        'feature_states': 'featureStates',
        'default_features': 'defaultFeatures',
        'imports': 'imports',
        'rollback_index': 'rollbackIndex',
        'bel_script_library_version': 'belScriptLibraryVersion',
        'source_microversion': 'sourceMicroversion',
        'reject_microversion_skew': 'rejectMicroversionSkew',
        'serialization_version': 'serializationVersion',
        'library_version': 'libraryVersion',
        'microversion_skew': 'microversionSkew',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, features=None, is_complete=None, feature_states=None, default_features=None, imports=None, rollback_index=None, bel_script_library_version=None, source_microversion=None, reject_microversion_skew=None, serialization_version=None, library_version=None, microversion_skew=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTFeatureListResponse - a model defined in OpenAPI"""  # noqa: E501

        self._features = None
        self._is_complete = None
        self._feature_states = None
        self._default_features = None
        self._imports = None
        self._rollback_index = None
        self._bel_script_library_version = None
        self._source_microversion = None
        self._reject_microversion_skew = None
        self._serialization_version = None
        self._library_version = None
        self._microversion_skew = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if features is not None:
            self.features = features
        if is_complete is not None:
            self.is_complete = is_complete
        if feature_states is not None:
            self.feature_states = feature_states
        if default_features is not None:
            self.default_features = default_features
        if imports is not None:
            self.imports = imports
        if rollback_index is not None:
            self.rollback_index = rollback_index
        if bel_script_library_version is not None:
            self.bel_script_library_version = bel_script_library_version
        if source_microversion is not None:
            self.source_microversion = source_microversion
        if reject_microversion_skew is not None:
            self.reject_microversion_skew = reject_microversion_skew
        if serialization_version is not None:
            self.serialization_version = serialization_version
        if library_version is not None:
            self.library_version = library_version
        if microversion_skew is not None:
            self.microversion_skew = microversion_skew
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def features(self):
        """Gets the features of this BTFeatureListResponse.  # noqa: E501


        :return: The features of this BTFeatureListResponse.  # noqa: E501
        :rtype: list[BTMFeature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this BTFeatureListResponse.


        :param features: The features of this BTFeatureListResponse.  # noqa: E501
        :type: list[BTMFeature]
        """

        self._features = features

    @property
    def is_complete(self):
        """Gets the is_complete of this BTFeatureListResponse.  # noqa: E501


        :return: The is_complete of this BTFeatureListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_complete

    @is_complete.setter
    def is_complete(self, is_complete):
        """Sets the is_complete of this BTFeatureListResponse.


        :param is_complete: The is_complete of this BTFeatureListResponse.  # noqa: E501
        :type: bool
        """

        self._is_complete = is_complete

    @property
    def feature_states(self):
        """Gets the feature_states of this BTFeatureListResponse.  # noqa: E501


        :return: The feature_states of this BTFeatureListResponse.  # noqa: E501
        :rtype: dict(str, BTFeatureState)
        """
        return self._feature_states

    @feature_states.setter
    def feature_states(self, feature_states):
        """Sets the feature_states of this BTFeatureListResponse.


        :param feature_states: The feature_states of this BTFeatureListResponse.  # noqa: E501
        :type: dict(str, BTFeatureState)
        """

        self._feature_states = feature_states

    @property
    def default_features(self):
        """Gets the default_features of this BTFeatureListResponse.  # noqa: E501


        :return: The default_features of this BTFeatureListResponse.  # noqa: E501
        :rtype: list[BTMFeature]
        """
        return self._default_features

    @default_features.setter
    def default_features(self, default_features):
        """Sets the default_features of this BTFeatureListResponse.


        :param default_features: The default_features of this BTFeatureListResponse.  # noqa: E501
        :type: list[BTMFeature]
        """

        self._default_features = default_features

    @property
    def imports(self):
        """Gets the imports of this BTFeatureListResponse.  # noqa: E501


        :return: The imports of this BTFeatureListResponse.  # noqa: E501
        :rtype: list[BTMImport]
        """
        return self._imports

    @imports.setter
    def imports(self, imports):
        """Sets the imports of this BTFeatureListResponse.


        :param imports: The imports of this BTFeatureListResponse.  # noqa: E501
        :type: list[BTMImport]
        """

        self._imports = imports

    @property
    def rollback_index(self):
        """Gets the rollback_index of this BTFeatureListResponse.  # noqa: E501


        :return: The rollback_index of this BTFeatureListResponse.  # noqa: E501
        :rtype: int
        """
        return self._rollback_index

    @rollback_index.setter
    def rollback_index(self, rollback_index):
        """Sets the rollback_index of this BTFeatureListResponse.


        :param rollback_index: The rollback_index of this BTFeatureListResponse.  # noqa: E501
        :type: int
        """

        self._rollback_index = rollback_index

    @property
    def bel_script_library_version(self):
        """Gets the bel_script_library_version of this BTFeatureListResponse.  # noqa: E501


        :return: The bel_script_library_version of this BTFeatureListResponse.  # noqa: E501
        :rtype: BTBelScriptLibraryVersion
        """
        return self._bel_script_library_version

    @bel_script_library_version.setter
    def bel_script_library_version(self, bel_script_library_version):
        """Sets the bel_script_library_version of this BTFeatureListResponse.


        :param bel_script_library_version: The bel_script_library_version of this BTFeatureListResponse.  # noqa: E501
        :type: BTBelScriptLibraryVersion
        """

        self._bel_script_library_version = bel_script_library_version

    @property
    def source_microversion(self):
        """Gets the source_microversion of this BTFeatureListResponse.  # noqa: E501


        :return: The source_microversion of this BTFeatureListResponse.  # noqa: E501
        :rtype: str
        """
        return self._source_microversion

    @source_microversion.setter
    def source_microversion(self, source_microversion):
        """Sets the source_microversion of this BTFeatureListResponse.


        :param source_microversion: The source_microversion of this BTFeatureListResponse.  # noqa: E501
        :type: str
        """

        self._source_microversion = source_microversion

    @property
    def reject_microversion_skew(self):
        """Gets the reject_microversion_skew of this BTFeatureListResponse.  # noqa: E501


        :return: The reject_microversion_skew of this BTFeatureListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._reject_microversion_skew

    @reject_microversion_skew.setter
    def reject_microversion_skew(self, reject_microversion_skew):
        """Sets the reject_microversion_skew of this BTFeatureListResponse.


        :param reject_microversion_skew: The reject_microversion_skew of this BTFeatureListResponse.  # noqa: E501
        :type: bool
        """

        self._reject_microversion_skew = reject_microversion_skew

    @property
    def serialization_version(self):
        """Gets the serialization_version of this BTFeatureListResponse.  # noqa: E501


        :return: The serialization_version of this BTFeatureListResponse.  # noqa: E501
        :rtype: str
        """
        return self._serialization_version

    @serialization_version.setter
    def serialization_version(self, serialization_version):
        """Sets the serialization_version of this BTFeatureListResponse.


        :param serialization_version: The serialization_version of this BTFeatureListResponse.  # noqa: E501
        :type: str
        """

        self._serialization_version = serialization_version

    @property
    def library_version(self):
        """Gets the library_version of this BTFeatureListResponse.  # noqa: E501


        :return: The library_version of this BTFeatureListResponse.  # noqa: E501
        :rtype: int
        """
        return self._library_version

    @library_version.setter
    def library_version(self, library_version):
        """Sets the library_version of this BTFeatureListResponse.


        :param library_version: The library_version of this BTFeatureListResponse.  # noqa: E501
        :type: int
        """

        self._library_version = library_version

    @property
    def microversion_skew(self):
        """Gets the microversion_skew of this BTFeatureListResponse.  # noqa: E501


        :return: The microversion_skew of this BTFeatureListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._microversion_skew

    @microversion_skew.setter
    def microversion_skew(self, microversion_skew):
        """Sets the microversion_skew of this BTFeatureListResponse.


        :param microversion_skew: The microversion_skew of this BTFeatureListResponse.  # noqa: E501
        :type: bool
        """

        self._microversion_skew = microversion_skew

    @property
    def type_id(self):
        """Gets the type_id of this BTFeatureListResponse.  # noqa: E501


        :return: The type_id of this BTFeatureListResponse.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTFeatureListResponse.


        :param type_id: The type_id of this BTFeatureListResponse.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTFeatureListResponse.  # noqa: E501


        :return: The connection_source of this BTFeatureListResponse.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTFeatureListResponse.


        :param connection_source: The connection_source of this BTFeatureListResponse.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTFeatureListResponse.  # noqa: E501


        :return: The export_type_name of this BTFeatureListResponse.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTFeatureListResponse.


        :param export_type_name: The export_type_name of this BTFeatureListResponse.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTFeatureListResponse.  # noqa: E501


        :return: The unknown_class of this BTFeatureListResponse.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTFeatureListResponse.


        :param unknown_class: The unknown_class of this BTFeatureListResponse.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTFeatureListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
